package org.fax4j.common;

import java.util.Map;

/**
 * Common interface for configuration holder components.
 * 
 * @author 	Sagie Gur-Ari
 * @version 1.0
 * @since	0.41.7
 */
public interface ConfigurationHolder
{
	/**
	 * Returns the configuration.
	 *  
	 * @return	The configuration
	 */
	public Map<String,String> getConfiguration();

	/**
	 * Returns the value from the component configuration based on the provided 
	 * configuration key.
	 * The value will be trimmed.<br>
	 * If the trimmed configuration value is an empty string,
	 * null will be returned instead.
	 *  
	 * @param 	key
	 * 			The configuration key
	 * @return	The value
	 */
	public String getConfigurationValue(String key);

	/**
	 * Returns the value from the component configuration based on the provided 
	 * configuration key.
	 * The value will be trimmed.<br>
	 * If the trimmed configuration value is an empty string,
	 * null will be returned instead.
	 *  
	 * @param 	key
	 * 			The configuration key (toString value will be used)
	 * @return	The value
	 */
	public String getConfigurationValue(Enum<?> key);
}