package org.fax4j.spi.http;

import org.fax4j.FaxException;
import org.fax4j.Provider;
import org.fax4j.common.Fax4JProvider;
import org.fax4j.spi.FaxClientSpi;
import org.fax4j.spi.http.CommonHTTPClientConfiguration.HTTPClientConfigurationConstants;

/**
 * This abstract HTTP client provides partial implementation for common functionality.
 * 
 * @author 	Sagie Gur-Ari
 * @version 1.03
 * @since	0.34
 */
public abstract class AbstractHTTPClient implements HTTPClient
{
	/**
	 * This is the default constructor.
	 */
	public AbstractHTTPClient()
	{
		super();
	}

	/**
	 * This function returns the provider.
	 * 
	 * @return	The provider
	 */
	public final Provider getProvider()
	{
		return Fax4JProvider.FAX4J_PROVIDER;
	}

	/**
	 * This function creates the HTTP client configuration to be
	 * used later on by this HTTP client type.
	 * 
	 * @param	faxClientSpi
	 * 			The fax client SPI
	 * @return	The HTTP client configuration
	 */
	public HTTPClientConfiguration createHTTPClientConfiguration(FaxClientSpi faxClientSpi)
	{
		//get server values
		String hostName=faxClientSpi.getConfigurationValue(HTTPClientConfigurationConstants.HOST_NAME_PROPERTY_KEY);
		if(hostName==null)
		{
			throw new FaxException("Host name not defined in property: "+HTTPClientConfigurationConstants.HOST_NAME_PROPERTY_KEY);
		}
		String value=faxClientSpi.getConfigurationValue(HTTPClientConfigurationConstants.PORT_PROPERTY_KEY);
		if(value==null)
		{
			value=String.valueOf(-1);
		}
		int port=Integer.parseInt(value);
		boolean ssl=Boolean.parseBoolean(faxClientSpi.getConfigurationValue(HTTPClientConfigurationConstants.SSL_PROPERTY_KEY));

		//create configuration
		CommonHTTPClientConfiguration configuration=new CommonHTTPClientConfiguration();
		
		//set values
		configuration.setHostName(hostName);
		configuration.setPort(port);
		configuration.setSSL(ssl);
		
		return configuration;
	}
}